@@ -2,7 +2,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -52,6 +52,9 @@ OS_NON_LINUX = (OS_MACOS, OS_WINDOWS)
 # simple Wayland detection
 if 'WAYLAND_DISPLAY' in os.environ or\
     'XDG_SESSION_TYPE' in os.environ and os.environ['XDG_SESSION_TYPE'] == 'wayland':
+    # dirty workaround to activate X11 support in Wayland environment - just a test
+    if not os.environ.get('QT_QPA_PLATFORM'):
+        os.environ['QT_QPA_PLATFORM'] = 'xcb'
     DESKTOP_WAYLAND = True
 else:
     DESKTOP_WAYLAND = False
@@ -65,6 +68,13 @@ if os.environ.get('CINNAMON_VERSION') or\
 else:
     DESKTOP_NEEDS_FIX = False
 
+# use QT platform plugins if not set otherwise on GNOME desktop
+# based on QGnomePlatform
+if not os.environ.get('QT_QPA_PLATFORMTHEME'):
+    if os.environ.get('XDG_SESSION_DESKTOP'):
+        if os.environ['XDG_SESSION_DESKTOP'].lower() == 'gnome':
+            os.environ['QT_QPA_PLATFORMTHEME'] = 'gnome'
+
 # queue.Queue() needs threading module which might be not such a good idea to be used
 # because QThread is already in use
 # maybe not the most logical place here to be defined but at least all
@@ -121,9 +131,9 @@ class AppInfo(object):
         contains app information previously located in GUI.py
     """
     NAME = 'Nagstamon'
-    VERSION = '3.12.0'
+    VERSION = '3.14.0'
     WEBSITE = 'https://nagstamon.de'
-    COPYRIGHT = '©2008-2023 Henri Wahl et al.'
+    COPYRIGHT = '©2008-2024 Henri Wahl et al.'
     COMMENTS = 'Nagios status monitor for your desktop'
     # dict of servers to offer for downloads if an update is available
     DOWNLOAD_SERVERS = {'nagstamon.de': 'https://github.com/HenriWahl/Nagstamon/releases'}
@@ -434,6 +444,9 @@ class Config(object):
         # time saving config
         try:
             for server in servers:
+                # server name needs to be a string at every cost
+                # see issue https://github.com/HenriWahl/Nagstamon/issues/1010
+                servers[server].name = str(servers[server].name)
                 # usernames for monitor server and proxy
                 servers[server].username = self.DeObfuscate(servers[server].username)
                 servers[server].proxy_username = self.DeObfuscate(servers[server].proxy_username)
@@ -751,14 +764,14 @@ class Config(object):
         """
         if OS == OS_WINDOWS:
             defaultactions = {"RDP": Action(name="RDP", description="Connect via RDP.",
-                                            type="command", string="C:\windows\system32\mstsc.exe /v:$ADDRESS$"),
+                                            type="command", string="C:/windows/system32/mstsc.exe /v:$ADDRESS$"),
                               "VNC": Action(name="VNC", description="Connect via VNC.",
-                                            type="command", string="C:\Program Files\TightVNC\vncviewer.exe $ADDRESS$"),
+                                            type="command", string="C:/Program Files/TightVNC/vncviewer.exe $ADDRESS$"),
                               "Telnet": Action(name="Telnet", description="Connect via Telnet.",
-                                               type="command", string="C:\Windows\System32\Telnet.exe root@$ADDRESS$"),
+                                               type="command", string="C:/Windows/System32\telnet.exe root@$ADDRESS$"),
                               "SSH": Action(name="SSH", description="Connect via SSH.",
                                             type="command",
-                                            string="C:\Program Files\PuTTY\putty.exe -l root $ADDRESS$")}
+                                            string="C:/Program Files/PuTTY/putty.exe -l root $ADDRESS$")}
         elif OS == OS_MACOS:
             defaultactions = {"RDP": Action(name="RDP", description="Connect via RDP.",
                                             type="command", string="open rdp://$ADDRESS$"),
@@ -966,9 +979,17 @@ class Server(object):
         self.alertmanager_filter = ''
         self.map_to_critical = 'critical,error'
         self.map_to_warning = 'warning,warn'
+        self.map_to_down = 'down'
         self.map_to_unknown = 'unknown'
         self.map_to_ok = 'ok'
 
+        # IcingaDBWebNotificationsServer
+        self.notification_filter = "user.name=*"
+        self.notification_lookback = "30 minutes"
+
+        # Thruk
+        self.disabled_backends = ""
+
 class Action(object):
     """
     class for custom actions, which whill be thrown into one config dictionary like the servers
