@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -453,8 +453,9 @@ def get_distro():
             os_release_dict = {}
             for line in os_release_file.read_text().splitlines():
                 if not line.startswith('#'):
-                    key, value = line.split('=', 1)
-                    os_release_dict[key] = value.strip('"').strip("'")
+                    try: key, value = line.split('=', 1)
+                    except ValueError: continue
+                    else: os_release_dict[key] = value.strip('"').strip("'")
             # Since CentOS Linux got retired by Red Hat, there are various RHEL derivatives/clones; flow is:
             # CentOS Stream -> Red Hat Enterprise Linux -> (AlmaLinux, EuroLinux, Oracle Linux, Rocky Linux)
             # Goal of this hack is to rule them all as Red Hat Enterprise Linux, the baseline distribution.
