@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -78,7 +78,7 @@ class CentreonServer(GenericServer):
 
         # check if any error occured
         errors_occured = self.check_for_error(data, error, status_code)
-        if errors_occured is not False:
+        if errors_occured is not None:
             return (errors_occured)
 
         self.centreon_version_major = int(data["web"]["major"])
@@ -95,8 +95,12 @@ class CentreonServer(GenericServer):
             # RestAPI version
             if self.centreon_version_major == 21:
                 self.restapi_version = "latest"
-            else:
+            elif self.centreon_version_major == 22:
                 self.restapi_version = "v22.04"
+            elif self.centreon_version_major == 23 and self.centreon_version_minor == 4:
+                self.restapi_version = "v23.04"
+            else:
+                self.restapi_version = "v23.10"
             if conf.debug_mode is True:
                 self.Debug(server='[' + self.get_name() + ']', debug='Centreon API version used : ' + self.restapi_version)
 
@@ -160,7 +164,7 @@ class CentreonServer(GenericServer):
 
             # check if any error occured
             errors_occured = self.check_for_error(data, error, status_code)
-            if errors_occured is not False:
+            if errors_occured is not None:
                 return (errors_occured)
 
             token = data["security"]["token"]
@@ -195,7 +199,7 @@ class CentreonServer(GenericServer):
 
             # check if any error occured
             errors_occured = self.check_for_error(data, error, status_code)
-            if errors_occured is not False:
+            if errors_occured is not None:
                 return (errors_occured)
 
             fqdn = str(data["result"][0]["fqdn"])
@@ -230,7 +234,7 @@ class CentreonServer(GenericServer):
 
                 # check if any error occured
                 errors_occured = self.check_for_error(data, error, status_code)
-                if errors_occured is not False:
+                if errors_occured is not None:
                     return (errors_occured)
 
                 host_id = data["result"][0]["id"]
@@ -264,7 +268,7 @@ class CentreonServer(GenericServer):
 
                 # check if any error occured
                 errors_occured = self.check_for_error(data, error, status_code)
-                if errors_occured is not False:
+                if errors_occured is not None:
                     return (errors_occured)
 
                 if host == "Meta_Services":
@@ -334,7 +338,7 @@ class CentreonServer(GenericServer):
 
             # check if any error occured
             errors_occured = self.check_for_error(data, error, status_code)
-            if errors_occured is not False:
+            if errors_occured is not None:
                 return (errors_occured)
 
             if data["meta"]["total"] == 0:
@@ -345,7 +349,7 @@ class CentreonServer(GenericServer):
                     self.new_hosts[new_host] = GenericHost()
                     self.new_hosts[new_host].name = alerts["name"]
                     self.new_hosts[new_host].server = self.name
-                    # API inconsistency, even by fixing exact version number
+                    # API inconsistency, even by fixing exact version number, changed starting with 22.04
                     if self.centreon_version_major == 21 or (self.centreon_version_major == 22 and self.centreon_version_minor == 4):
                         self.new_hosts[new_host].criticality = alerts["severity_level"]
                     else:
@@ -356,13 +360,20 @@ class CentreonServer(GenericServer):
                     self.new_hosts[new_host].duration = alerts["duration"]
                     self.new_hosts[new_host].attempt = alerts["tries"]
                     self.new_hosts[new_host].status_information = alerts["information"]
-                    self.new_hosts[new_host].passiveonly = alerts["passive_checks"]
-                    self.new_hosts[new_host].notifications_disabled = not alerts["notification_enabled"]
+                    # Change starting with 23.10
+                    if (self.centreon_version_major >= 23 and self.centreon_version_minor >= 10) or self.centreon_version_major > 23:
+                        self.new_hosts[new_host].passiveonly = alerts["has_passive_checks_enabled"]
+                        self.new_hosts[new_host].notifications_disabled = not alerts["is_notification_enabled"]
+                        self.new_hosts[new_host].acknowledged = alerts["is_acknowledged"]
+                        self.new_hosts[new_host].scheduled_downtime = alerts["is_in_downtime"]
+                    else:
+                        self.new_hosts[new_host].passiveonly = alerts["passive_checks"]
+                        self.new_hosts[new_host].notifications_disabled  = not alerts["notification_enabled"]
+                        self.new_hosts[new_host].acknowledged = alerts["acknowledged"]
+                        self.new_hosts[new_host].scheduled_downtime = alerts["in_downtime"]
                     # avoid crash if flapping is not configured in Centreon
                     # according to https://github.com/HenriWahl/Nagstamon/issues/866#issuecomment-1302257034
                     self.new_hosts[new_host].flapping = alerts.get("flapping", False)
-                    self.new_hosts[new_host].acknowledged = alerts["acknowledged"]
-                    self.new_hosts[new_host].scheduled_downtime = alerts["in_downtime"]
                     if "(S)" in alerts["tries"]:
                         self.new_hosts[new_host].status_type = self.HARD_SOFT['(S)']
                     else:
@@ -391,7 +402,7 @@ class CentreonServer(GenericServer):
 
             # check if any error occured
             errors_occured = self.check_for_error(data, error, status_code)
-            if errors_occured is not False:
+            if errors_occured is not None:
                 return (errors_occured)
 
             if data["meta"]["total"] == 0:
@@ -423,18 +434,25 @@ class CentreonServer(GenericServer):
                     self.new_hosts[new_host].services[new_service].duration = alerts["duration"]
                     self.new_hosts[new_host].services[new_service].attempt = alerts["tries"]
                     self.new_hosts[new_host].services[new_service].status_information = alerts["information"]
-                    self.new_hosts[new_host].services[new_service].passiveonly = alerts["passive_checks"]
-                    self.new_hosts[new_host].services[new_service].notifications_disabled = not alerts["notification_enabled"]
+                    # Change starting with 23.10
+                    if (self.centreon_version_major >= 23 and self.centreon_version_minor >= 10) or self.centreon_version_major > 23:
+                        self.new_hosts[new_host].services[new_service].passiveonly = alerts["has_passive_checks_enabled"]
+                        self.new_hosts[new_host].services[new_service].notifications_disabled = not alerts["is_notification_enabled"]
+                        self.new_hosts[new_host].services[new_service].acknowledged = alerts["is_acknowledged"]
+                        self.new_hosts[new_host].services[new_service].scheduled_downtime = alerts["is_in_downtime"]
+                    else:
+                        self.new_hosts[new_host].services[new_service].passiveonly = alerts["passive_checks"]
+                        self.new_hosts[new_host].services[new_service].notifications_disabled = not alerts["notification_enabled"]
+                        self.new_hosts[new_host].services[new_service].acknowledged = alerts["acknowledged"]
+                        self.new_hosts[new_host].services[new_service].scheduled_downtime = alerts["in_downtime"]
                     # avoid crash if flapping is not configured in Centreon
                     # according to https://github.com/HenriWahl/Nagstamon/issues/866#issuecomment-1302257034
                     self.new_hosts[new_host].services[new_service].flapping = alerts.get("flapping", False)
-                    self.new_hosts[new_host].services[new_service].acknowledged = alerts["acknowledged"]
-                    self.new_hosts[new_host].services[new_service].scheduled_downtime = alerts["in_downtime"]
                     if "(S)" in alerts["tries"]:
                         self.new_hosts[new_host].services[new_service].status_type = self.HARD_SOFT['(S)']
                     else:
                         self.new_hosts[new_host].services[new_service].status_type = self.HARD_SOFT['(H)']
-                    # API inconsistency, even by fixing exact version number
+                    # API inconsistency, even by fixing exact version number, changed starting with 22.04
                     if self.centreon_version_major == 21 or (self.centreon_version_major == 22 and self.centreon_version_minor == 4):
                         self.new_hosts[new_host].services[new_service].criticality = alerts["severity_level"]
                     else:
@@ -549,6 +567,15 @@ class CentreonServer(GenericServer):
             ]
         }
 
+        # This new parameter was added in 23.04
+        if self.centreon_version_major >= 23:
+            property_to_add = {
+                "check": {
+                    "is_forced": True
+                }
+            }
+            rechecks.update(property_to_add)
+
         try:
             # Host
             if service == '':
