@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@ import socket
 import sys
 import traceback
 import urllib.parse
+from typing import Optional
 from urllib.request import getproxies
 
 from bs4 import BeautifulSoup
@@ -60,6 +61,8 @@ from Nagstamon.Config import (AppInfo,
                               OS_MACOS,
                               RESOURCES)
 
+# flag to keep track of Kerberos availability
+KERBEROS_AVAILABLE = False
 if OS == OS_MACOS:
     # requests_gssapi is newer but not available everywhere
     try:
@@ -67,16 +70,18 @@ if OS == OS_MACOS:
         import numbers
         import gssapi.raw.cython_converters
         from requests_gssapi import HTTPSPNEGOAuth as HTTPSKerberos
-    except ImportError:
-        from requests_kerberos import HTTPKerberosAuth as HTTPSKerberos
+        KERBEROS_AVAILABLE = True
+    except ImportError as error:
+        print(error)
 else:
     # requests_gssapi is newer but not available everywhere
     try:
         # requests_gssapi needs installation of KfW - Kerberos for Windows
         # requests_kerberoes doesn't
         from requests_kerberos import HTTPKerberosAuth as HTTPSKerberos
-    except ImportError:
-        from requests_gssapi import HTTPSPNEGOAuth as HTTPSKerberos
+        KERBEROS_AVAILABLE = True
+    except ImportError as error:
+        print(error)
 
 # disable annoying SubjectAltNameWarning warnings
 try:
@@ -258,6 +263,13 @@ class GenericServer(object):
         # Zabbix
         self.use_description_name_service = None
 
+        # IcingaDBWebNotifications
+        self.notification_filter = None
+        self.notification_lookback = None
+
+        # Thruk
+        self.disabled_backends = None
+
     def init_config(self):
         '''
             set URLs for CGI - they are static and there is no need to set them with every cycle
@@ -314,7 +326,7 @@ class GenericServer(object):
             session.auth = requests.auth.HTTPDigestAuth(self.username, self.password)
         elif self.authentication == 'ecp' and ECP_AVAILABLE:
             session.auth = HTTPECPAuth(self.idp_ecp_endpoint, username=self.username, password=self.password)
-        elif self.authentication == 'kerberos':
+        elif self.authentication == 'kerberos' and KERBEROS_AVAILABLE:
             session.auth = HTTPSKerberos()
         elif self.authentication == 'bearer':
             session.auth = BearerAuth(self.password)
@@ -351,7 +363,7 @@ class GenericServer(object):
                 if self.proxy_username == self.proxy_password == '':
                     user_pass = ''
                 else:
-                    user_pass = '{0}:{1}@'.format(self.proxy_username, self.proxy_password)
+                    user_pass = '{0}:{1}'.format(self.proxy_username, self.proxy_password)
 
                 # split and analyze proxy URL
                 proxy_address_parts = self.proxy_address.split('//')
@@ -361,7 +373,7 @@ class GenericServer(object):
                 # use only valid schemes
                 if scheme.lower() in ('http:', 'https:', 'socks5:', 'socks5h:'):
                     # merge proxy URL
-                    proxy_url = '{0}//{1}{2}'.format(scheme, user_pass, host_port)
+                    proxy_url = f'{scheme}//{user_pass}@{host_port}/'
                     # fill session.proxies for both protocols
                     requester.proxies = {'http': proxy_url, 'https': proxy_url}
         else:
@@ -639,7 +651,7 @@ class GenericServer(object):
                 # check if any error occured
                 errors_occured = self.check_for_error(htobj, error, status_code)
                 # if there are errors return them
-                if errors_occured is not False:
+                if errors_occured is not None:
                     return(errors_occured)
 
                 # put a copy of a part of htobj into table to be able to delete htobj
@@ -764,7 +776,7 @@ class GenericServer(object):
                 # check if any error occured
                 errors_occured = self.check_for_error(htobj, error, status_code)
                 # if there are errors return them
-                if errors_occured is not False:
+                if errors_occured is not None:
                     return(errors_occured)
 
                 # too much copy.deepcopy()s here give recursion crashs
@@ -1687,16 +1699,17 @@ class GenericServer(object):
         """
         return(len(list((e for e in self.events_history if self.events_history[e] is True))))
 
-    def check_for_error(self, result, error, status_code):
+    @staticmethod
+    def check_for_error(result, error, status_code) -> Optional[Result]:
         """
             check if any error occured - if so, return error
         """
         if error != '' or status_code > 400:
-            return(Result(result=copy.deepcopy(result),
+            return Result(result=copy.deepcopy(result),
                           error=copy.deepcopy(error),
-                          status_code=copy.deepcopy(status_code)))
+                          status_code=copy.deepcopy(status_code))
         else:
-            return(False)
+            return None
 
     def get_worst_status_current(self):
         """
