@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@ import sys
 import copy
 import json
 import datetime
+from datetime import timezone
 import socket
 
 from bs4 import BeautifulSoup
@@ -60,13 +61,13 @@ class IcingaDBWebServer(GenericServer):
     """
     TYPE = 'IcingaDBWeb'
     MENU_ACTIONS = ['Monitor', 'Recheck', 'Acknowledge', 'Submit check result', 'Downtime']
-    STATES_MAPPING = {'hosts' : {0 : 'UP', 1 : 'DOWN', 2 : 'UNREACHABLE'}, \
+    STATES_MAPPING = {'hosts' : {0 : 'UP', 1 : 'DOWN', 2 : 'UNREACHABLE'},
                      'services' : {0 : 'OK', 1 : 'WARNING', 2 : 'CRITICAL', 3 : 'UNKNOWN'}}
-    STATES_MAPPING_REV = {'hosts' : { 'UP': 0, 'DOWN': 1, 'UNREACHABLE': 2}, \
+    STATES_MAPPING_REV = {'hosts' : { 'UP': 0, 'DOWN': 1, 'UNREACHABLE': 2},
                      'services' : {'OK': 0, 'WARNING': 1, 'CRITICAL': 2, 'UNKNOWN': 3}}
-    BROWSER_URLS = { 'monitor': '$MONITOR-CGI$/dashboard', \
-                    'hosts': '$MONITOR-CGI$/icingadb/hosts', \
-                    'services': '$MONITOR-CGI$/icingadb/services', \
+    BROWSER_URLS = { 'monitor': '$MONITOR-CGI$/dashboard',
+                    'hosts': '$MONITOR-CGI$/icingadb/hosts',
+                    'services': '$MONITOR-CGI$/icingadb/services',
                     'history': '$MONITOR-CGI$/icingadb/history'}
 
 
@@ -120,10 +121,10 @@ class IcingaDBWebServer(GenericServer):
             Get status from Icinga Server - only JSON
         """
         # define CGI URLs for hosts and services
-        if self.cgiurl_hosts == self.cgiurl_services == self.cgiurl_monitoring_health == None:
+        if self.cgiurl_hosts is None and self.cgiurl_services is None and self.cgiurl_monitoring_health is None:
             # services (unknown, warning or critical?)
-            self.cgiurl_services = {'hard': self.monitor_cgi_url + '/icingadb/services?service.state.is_problem=y&service.state.in_downtime=n&service.state.state_type=hard&columns=service.state.last_update,service.state.is_reachable&format=json', \
-                                    'soft': self.monitor_cgi_url + '/icingadb/services?service.state.is_problem=y&service.state.in_downtime=n&service.state.state_type=soft&columns=service.state.last_update,service.state.is_reachable&format=json'}
+            self.cgiurl_services = {'hard': self.monitor_cgi_url + '/icingadb/services?service.state.is_problem=y&service.state.state_type=hard&columns=service.state.last_update,service.state.is_reachable&format=json', \
+                                    'soft': self.monitor_cgi_url + '/icingadb/services?service.state.is_problem=y&service.state.state_type=soft&columns=service.state.last_update,service.state.is_reachable&format=json'}
             # hosts (up or down or unreachable)
             self.cgiurl_hosts = {'hard': self.monitor_cgi_url + '/icingadb/hosts?host.state.is_problem=y&host.state.state_type=hard&columns=host.state.last_update&format=json', \
                                  'soft': self.monitor_cgi_url + '/icingadb/hosts?host.state.is_problem=y&host.state.state_type=soft&columns=host.state.last_update&format=json'}
@@ -159,13 +160,10 @@ class IcingaDBWebServer(GenericServer):
                                               copy.deepcopy(result.error),\
                                               result.status_code
 
-                if error != '' or status_code >= 400:
-                    return Result(result=jsonraw,
-                                  error=error,
-                                  status_code=status_code)
-
                 # check if any error occured
-                self.check_for_error(jsonraw, error, status_code)
+                potential_error = self.check_for_error(jsonraw, error, status_code)
+                if potential_error is not None:
+                    return potential_error
 
                 # Check if the backend is running
                 # If it isn't running the last values stored in the database are returned/shown
@@ -211,9 +209,13 @@ class IcingaDBWebServer(GenericServer):
                         else:
                             self.new_hosts[host_name].status = self.STATES_MAPPING['hosts'][int(h['state']['soft_state'])]
 
-                        self.new_hosts[host_name].last_check = datetime.datetime.fromtimestamp(int(float(h['state']['last_update'])))
+                        if h['state']['last_update'].replace(".", "").isnumeric(): # new version of icingadb doesnt return unix timestamp
+                            self.new_hosts[host_name].last_check = datetime.datetime.fromtimestamp(int(float(h['state']['last_update'])))
+                        else:
+                            self.new_hosts[host_name].last_check = datetime.datetime.fromisoformat(h['state']['last_update'])
+                        
                         self.new_hosts[host_name].attempt = "{}/{}".format(h['state']['check_attempt'],h['max_check_attempts'])
-                        self.new_hosts[host_name].status_information = BeautifulSoup(h['state']['output'].replace('\n', ' ').strip(), 'html.parser').text
+                        self.new_hosts[host_name].status_information = BeautifulSoup(str(h['state']['output']).replace('\n', ' ').strip(), 'html.parser').text
                         self.new_hosts[host_name].passiveonly = not int(h.get('active_checks_enabled') or '0')
                         self.new_hosts[host_name].notifications_disabled = not int(h.get('notifications_enabled') or '0')
                         self.new_hosts[host_name].flapping = bool(int(h['state']['is_flapping'] or 0))
@@ -234,11 +236,17 @@ class IcingaDBWebServer(GenericServer):
                                 self.new_hosts[host_name].attempt = "HARD"
 
                         # extra duration needed for calculation
-                        if h['state']['last_state_change'] is not None and h['state']['last_state_change'] != 0:
-                            duration = datetime.datetime.now() - datetime.datetime.fromtimestamp(int(float(h['state']['last_state_change'])))
-                            self.new_hosts[host_name].duration = strfdelta(duration,'{days}d {hours}h {minutes}m {seconds}s')
-                        else:
-                            self.new_hosts[host_name].duration = 'n/a'
+                        self.new_hosts[host_name].duration = 'n/a'
+                        if h['state']['last_state_change'] is not None:
+                            if h['state']['last_state_change'].replace(".", "").isnumeric(): # new version of icingadb doesnt return unix timestamp
+                                duration = datetime.datetime.now() - datetime.datetime.fromtimestamp(int(float(h['state']['last_state_change'])))
+                            else:
+                                last_state_change = datetime.datetime.fromisoformat(h['state']['last_state_change'])
+                                duration = datetime.datetime.now(timezone.utc).astimezone() - last_state_change
+                            
+                            if duration.total_seconds() > 0:
+                                self.new_hosts[host_name].duration = strfdelta(duration,'{days}d {hours}h {minutes}m {seconds}s')
+
                     del h, host_name
         except:
             import traceback
@@ -303,9 +311,14 @@ class IcingaDBWebServer(GenericServer):
                             self.new_hosts[host_name].services[service_name].status = self.STATES_MAPPING['services'][int(s['state']['hard_state'])]
                         else:
                             self.new_hosts[host_name].services[service_name].status = self.STATES_MAPPING['services'][int(s['state']['soft_state'])]
-                        self.new_hosts[host_name].services[service_name].last_check = datetime.datetime.fromtimestamp(int(float(s['state']['last_update'])))
+
+                        if s['state']['last_update'].replace(".", "").isnumeric(): # new version of icingadb doesnt return unix timestamp
+                            self.new_hosts[host_name].services[service_name].last_check = datetime.datetime.fromtimestamp(int(float(s['state']['last_update'])))
+                        else:
+                            self.new_hosts[host_name].services[service_name].last_check = datetime.datetime.fromisoformat(s['state']['last_update'])
+
                         self.new_hosts[host_name].services[service_name].attempt = "{}/{}".format(s['state']['check_attempt'],s['max_check_attempts'])
-                        self.new_hosts[host_name].services[service_name].status_information = BeautifulSoup(s['state']['output'].replace('\n', ' ').strip(), 'html.parser').text
+                        self.new_hosts[host_name].services[service_name].status_information = BeautifulSoup(str(s['state']['output']).replace('\n', ' ').strip(), 'html.parser').text
                         self.new_hosts[host_name].services[service_name].passiveonly = not int(s.get('active_checks_enabled') or '0')
                         self.new_hosts[host_name].services[service_name].notifications_disabled = not int(s.get('notifications_enabled') or '0')
                         self.new_hosts[host_name].services[service_name].flapping = bool(int(s['state']['is_flapping'] or 0))
@@ -330,11 +343,16 @@ class IcingaDBWebServer(GenericServer):
                                 self.new_hosts[host_name].services[service_name].attempt = "HARD"
 
                         # extra duration needed for calculation
-                        if s['state']['last_state_change'] is not None and s['state']['last_state_change'] != 0:
-                            duration = datetime.datetime.now() - datetime.datetime.fromtimestamp(int(float(s['state']['last_state_change'])))
-                            self.new_hosts[host_name].services[service_name].duration = strfdelta(duration, '{days}d {hours}h {minutes}m {seconds}s')
-                        else:
-                            self.new_hosts[host_name].services[service_name].duration = 'n/a'
+                        self.new_hosts[host_name].services[service_name].duration = 'n/a'
+                        if s['state']['last_state_change'] is not None:
+                            if s['state']['last_update'].replace(".", "").isnumeric(): # new version of icingadb doesnt return unix timestamp
+                                duration = datetime.datetime.now() - datetime.datetime.fromtimestamp(int(float(s['state']['last_state_change'])))
+                            else:
+                                last_state_change = datetime.datetime.fromisoformat(s['state']['last_state_change'])
+                                duration = datetime.datetime.now(timezone.utc).astimezone() - last_state_change
+                            
+                            if duration.total_seconds() > 0:
+                                self.new_hosts[host_name].services[service_name].duration = strfdelta(duration, '{days}d {hours}h {minutes}m {seconds}s')
 
                     del s, host_name, service_name
         except:
@@ -442,15 +460,21 @@ class IcingaDBWebServer(GenericServer):
         #if not info_dict['expire_time']:
         #    info_dict['expire_time'] = None
 
-        self._set_acknowledge(info_dict['host'],
-                              info_dict['service'],
-                              info_dict['author'],
-                              info_dict['comment'],
-                              info_dict['sticky'],
-                              info_dict['notify'],
-                              info_dict['persistent'],
-                              all_services,
-                              info_dict['expire_time'])
+        try:
+            self._set_acknowledge(info_dict['host'],
+                                  info_dict['service'],
+                                  info_dict['author'],
+                                  info_dict['comment'],
+                                  info_dict['sticky'],
+                                  info_dict['notify'],
+                                  info_dict['persistent'],
+                                  all_services,
+                                  info_dict['expire_time'])
+        except:
+            import traceback
+            traceback.print_exc(file=sys.stdout)
+            result, error = self.Error(sys.exc_info())
+            return Result(result=result, error=error)
 
 
     def _set_acknowledge(self, host, service, author, comment, sticky, notify, persistent, all_services=None, expire_time=None):
@@ -731,9 +755,14 @@ class IcingaDBWebServer(GenericServer):
 
 
     def open_monitor(self, host, service=''):
-        '''
-            open monitor from tablewidget context menu
-        '''
+        """Open monitor from tablewidget context menu."""
+        if host not in self.hosts:
+            print("Cannot find {}. Skipping!".format(host))
+            return
+        if service and service not in self.hosts[host].services:
+            print("Cannot find {}::{}. Skipping!".format(host, service))
+            return
+
         # only type is important so do not care of service '' in case of host monitor
         if service == '':
             url = '{0}/icingadb/hosts?host.state.is_problem=y&sort=host.state.severity#!{1}/icingadb/host?{2}'.format(self.monitor_url,
