@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -124,8 +124,8 @@ class MultisiteServer(GenericServer):
                 # if no cookie yet login
                 self._get_cookie_login()
         elif self.CookieAuth and self.refresh_authentication:
-            if self.session is None:
-                self.session = self.create_session()
+            #if self.session is None:
+            self.session = self.create_session()
 
             # force re-auth
             self._get_cookie_login()
@@ -179,18 +179,21 @@ class MultisiteServer(GenericServer):
         #        return ''
 
         # looks like cookieauth
-        elif content.startswith('<'):
+        elif content.startswith('<') or\
+                '<!DOCTYPE html>' in content:
             self.CookieAuth = True
             # if first attempt login and then try to get data again
             if not self._is_auth_in_cookies():
                 self._get_cookie_login()
                 result = self.FetchURL(url, 'raw')
                 content, error = result.result, result.error
-                if content.startswith('<'):
+                if content.startswith('<') or\
+                '<!DOCTYPE html>' in content:
                     return ''
 
         # if finally still some <HTML> is sent this looks like a new login due to password change
-        if content.startswith('<'):
+        if content.startswith('<') or\
+                '<!DOCTYPE html>' in content:
             self.refresh_authentication = True
             return ''
 
