@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 #
 # Based on https://github.com/duncs/Nagstamon by @duncs
 #
@@ -244,7 +244,7 @@ class OpsviewServer(GenericServer):
             # check if any error occured
             errors_occured = self.check_for_error(data, error, status_code)
             # if there are errors return them
-            if errors_occured:
+            if errors_occured is not None:
                 return errors_occured
                 
             if conf.debug_mode:
