@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 # Thruk additions copyright by dcec@Github
 #
 # This program is free software; you can redistribute it and/or modify
@@ -135,6 +135,9 @@ class ThrukServer(GenericServer):
                 self.refresh_authentication = True
                 return Result(result=None, error="Login failed")
 
+        if self.disabled_backends is not None:
+            self.session.cookies.set('thruk_backends', '&'.join((f"{v}=2" for v in self.disabled_backends.split(','))))
+            print(self.session.cookies.get('thruk_backends'))
 
     def open_monitor(self, host, service=''):
         '''
@@ -279,7 +282,7 @@ class ThrukServer(GenericServer):
             # check if any error occured
             errors_occured = self.check_for_error(jsonraw, error, status_code)
             # if there are errors return them
-            if errors_occured:
+            if errors_occured is not None:
                 return(errors_occured)
 
             # in case basic auth did not work try form login cookie based login
@@ -327,7 +330,7 @@ class ThrukServer(GenericServer):
             # check if any error occured
             errors_occured = self.check_for_error(jsonraw, error, status_code)
             # if there are errors return them
-            if errors_occured:
+            if errors_occured is not None:
                 return(errors_occured)
 
             # in case basic auth did not work try form login cookie based login
