@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@ from Nagstamon.Servers.Centreon import CentreonServer
 from Nagstamon.Servers.Icinga import IcingaServer
 from Nagstamon.Servers.IcingaWeb2 import IcingaWeb2Server
 from Nagstamon.Servers.IcingaDBWeb import IcingaDBWebServer
+from Nagstamon.Servers.IcingaDBWebNotifications import IcingaDBWebNotificationsServer
 from Nagstamon.Servers.Multisite import MultisiteServer
 from Nagstamon.Servers.op5Monitor import Op5MonitorServer
 from Nagstamon.Servers.Opsview import OpsviewServer
@@ -190,6 +191,10 @@ def create_server(server=None):
     # IcingaWeb2
     new_server.no_cookie_auth = server.no_cookie_auth
 
+    # IcingaDBWebNotifications
+    new_server.notification_filter = server.notification_filter
+    new_server.notification_lookback = server.notification_lookback
+
     # Checkmk Multisite
     new_server.force_authuser = server.force_authuser
     new_server.checkmk_view_hosts = server.checkmk_view_hosts
@@ -215,7 +220,10 @@ def create_server(server=None):
     new_server.map_to_unknown = server.map_to_unknown
     new_server.map_to_warning = server.map_to_warning
     new_server.map_to_critical = server.map_to_critical
+    new_server.map_to_down = server.map_to_down
 
+    # Thruk
+    new_server.disabled_backends = server.disabled_backends
 
     # server's individual preparations for HTTP connections (for example cookie creation)
     # is done in GetStatus() method of monitor
@@ -237,6 +245,7 @@ servers_list = [AlertmanagerServer,
                 CentreonServer,
                 IcingaServer,
                 IcingaDBWebServer,
+                IcingaDBWebNotificationsServer,
                 IcingaWeb2Server,
                 LivestatusServer,
                 Monitos3Server,
