@@ -1,7 +1,7 @@
 # encoding: utf-8
 
 # Nagstamon - Nagios status monitor for your desktop
-# Copyright (C) 2008-2023 Henri Wahl <henri@nagstamon.de> et al.
+# Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -151,7 +151,7 @@ class Op5MonitorServer(GenericServer):
             # check if any error occured
             errors_occured = self.check_for_error(data, error, status_code)
             # if there are errors return them
-            if errors_occured:
+            if errors_occured is not None:
                 return(errors_occured)    
                            
             if data['count']:
@@ -212,7 +212,7 @@ class Op5MonitorServer(GenericServer):
             # check if any error occured
             errors_occured = self.check_for_error(data, error, status_code)
             # if there are errors return them
-            if errors_occured:
+            if errors_occured is not None:
                 return(errors_occured)    
 
             if data['count']:
